==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Output/alsa/translations/alsa_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh_CN">
<defaultcodec></defaultcodec>
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>ALSA 插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="50"/>
        <source>About ALSA Output Plugin</source>
        <translation>关于 ALSA 输出插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="51"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Qmmp ALSA 输出插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Device Settings</source>
        <translation>设备设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Audio device</source>
        <translation>音频设备</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Mixer</source>
        <translation>混频</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="106"/>
        <source>Mixer card:</source>
        <translation>混频卡：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Mixer device:</source>
        <translation>混频设备：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>Advanced Settings</source>
        <translation>高级设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="154"/>
        <source>Soundcard</source>
        <translation>声卡</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="160"/>
        <source>Buffer time (ms):</source>
        <translation>缓冲时间(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="196"/>
        <source>Period time (ms):</source>
        <translation>周期时间(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="272"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>ALSA Plugin Settings</source>
        <translation>ALSA 插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="232"/>
        <source>Use mmap access</source>
        <translation>使用内存映射</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Output/alsa/translations/alsa_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>ALSA 插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>About ALSA Output Plugin</source>
        <translation>关于 ALSA 输出插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Qmmp ALSA 输出插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="24"/>
        <source>Device Settings</source>
        <translation>设备设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="36"/>
        <source>Audio device</source>
        <translation>音频设备</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Mixer</source>
        <translation>混频</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Mixer card:</source>
        <translation>混频卡：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="73"/>
        <source>Mixer device:</source>
        <translation>混频设备：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Advanced Settings</source>
        <translation>高级设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="102"/>
        <source>Soundcard</source>
        <translation>声卡</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="108"/>
        <source>Buffer time (ms):</source>
        <translation>缓冲时间(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="144"/>
        <source>Period time (ms):</source>
        <translation>周期时间(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>ALSA 插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="180"/>
        <source>Use mmap access</source>
        <translation>使用内存映射</translation>
    </message>
</context>
</TS>
